HealthCheckModule class
HealthCheckModule is a Serinus module that provides a health check endpoint and service.
indicators is a list of HealthIndicator instances that will be checked when the health endpoint is called.
errorLogStyle determines how errors are logged when a health check fails. By default, it is set to ErrorLogStyle.none, which means no error logging will occur.
path is an optional parameter that allows you to customize the endpoint path for health checks. If not provided, it defaults to '/health'.
Constructors
-
HealthCheckModule({required List<
HealthIndicator> indicators, ErrorLogStyle errorLogStyle = ErrorLogStyle.none, String? path}) - Creates a HealthCheckModule with the specified indicators, error logging style, and optional path.
Properties
-
controllers
↔ List<
Controller> -
The
controllersproperty contains the controllers of the module.getter/setter pairinherited -
exportedProviders
→ List<
Provider> -
The
optionsproperty contains the options of the module.no setterinherited -
exports
↔ List<
Type> -
The
exportsproperty contains the exports of the module.getter/setter pairinherited - hashCode → int
-
The hash code for this object.
no setterinherited
-
imports
↔ List<
Module> -
The
importsproperty contains the modules that are imported in the module.getter/setter pairinherited - isGlobal → bool
-
The
isGlobalproperty is used to define if the module is global.finalinherited -
providers
↔ List<
Provider> -
The
providersproperty contains the providers of the module.getter/setter pairinherited - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- token → String
-
The
importsproperty contains the modules that are imported in the module.finalinherited
Methods
-
configure(
MiddlewareConsumer consumer) → void -
Configures the middleware for the module.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
registerAsync(
ApplicationConfig config) → Future< DynamicModule> -
The
registermethod is used to register the module.inherited -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited