MemoryHealthIndicator class

A health indicator that checks if the process's Resident Set Size (RSS) is within a specified threshold.

Inheritance

Constructors

MemoryHealthIndicator(String _name, {required int maxRssBytes})
Creates a memory threshold indicator.

Properties

hashCode int
The hash code for this object.
no setterinherited
maxRssBytes int
final
name String
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
pingCheck(RequestContext _) Future<HealthIndicatorCheck>
Returns a map with the status of the specific component. Throws an exception if the component is critically failing.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited