indicators/indicators library
Classes
- DiskSpaceHealthIndicator
- A health indicator that checks if the disk usage of a specified path is below a certain threshold.
- HttpPingIndicator
- A health indicator that performs an HTTP GET request to a specified URL and checks the response status code.
- LoxiaHealthIndicator
- A health indicator that checks the connectivity to a Loxia datasource by performing a simple query.
- MemoryHealthIndicator
- A health indicator that checks if the process's Resident Set Size (RSS) is within a specified threshold.